searchData={"items":[{"type":"module","title":"MainProxy","doc":"Route requests to other Phoenix Endpoints or Plugs with WebSocket support.\n\n> This library is useful for Gigalixir, Render, Heroku or other deployments where only one web port is exposed.","ref":"MainProxy.html"},{"type":"module","title":"Installation - MainProxy","doc":"Add MainProxy to your list of dependencies in `mix.exs`.\n\n> If you are running an umbrella project, adding MainProxy as a dependency at the root `mix.exs` won't work. Instead, either add it to one of your child apps or create a new child app solely for the proxy.\n\n```elixir\ndef deps do\n  [\n    {:main_proxy, \"~> 0.1\"},\n  ]\nend\n```","ref":"MainProxy.html#module-installation"},{"type":"module","title":"Usage - MainProxy","doc":"Configure listening options for MainProxy:\n\n```elixir\nconfig :main_proxy,\n  http: [port: 4080],\n  https: [port: 4443]\n```\n\nCreate a proxy module which configures backends:\n\n```elixir\ndefmodule MyApp.Proxy do\n  use MainProxy.Proxy\n\n  @impl MainProxy.Proxy\n  def backends do\n    [\n      %{\n        domain: \"my-cool-app.com\",\n        phoenix_endpoint: MyAppWeb.Endpoint\n      },\n      %{\n        domain: \"members.my-cool-app.com\",\n        phoenix_endpoint: MyAppMembersWeb.Endpoint\n      },\n      %{\n        verb: ~r/get/i,\n        path: ~r{^/main-proxy-plug-test$},\n        plug: MainProxy.Plug.Test,\n        opts: [1, 2, 3]\n      }\n    ]\n  end\nend\n```\n\n> Backends can also be configured via configuration:\n>\n> ```elixir\n> config :main_proxy,\n>   http: [port: 4080],\n>   https: [port: 4443],\n>   backends: [\n>     # ...\n>   ]\n> ```\n>\n> But, it's not the recommended way.\n\nAdd above created proxy module to the supervision tree:\n\n```elixir\nchildren = [\n  # ... other children\n  MyApp.Proxy,\n]\n```\n\nConfigure all endpoints to not start a server in order to avoid endpoints bypassing MainProxy:\n\n```elixir\n# ...\nconfig :my_app, MyAppWeb.Endpoint, server: false\nconfig :my_app_members, MyAppMembersWeb.Endpoint, server: false\n```","ref":"MainProxy.html#module-usage"},{"type":"module","title":"Available Configuration Options - MainProxy","doc":"- `:http` - the configuration for the HTTP server. It accepts all options as defined by [Plug.Cowboy](https://hexdocs.pm/plug_cowboy/).\n- `:https` - the configuration for the HTTPS server. It accepts all options as defined by [Plug.Cowboy](https://hexdocs.pm/plug_cowboy/).\n- `:server` - `true` by default. If you are running application with `mix phx.server`, this option is ignored, and the server will always be started.\n- `:backends` - the rule for routing requests:\n  - `:domain`\n  - `:verb`\n  - `:host`\n  - `:path`\n  - `:phoenix_endpoint` / `:plug`\n  - `:opts` - only for `:plug`\n- `:log_requests` - `true` by default. Log the requests or not.","ref":"MainProxy.html#module-available-configuration-options"},{"type":"module","title":"MainProxy.Plug","doc":"","ref":"MainProxy.Plug.html"},{"type":"function","title":"MainProxy.Plug.call/2","doc":"","ref":"MainProxy.Plug.html#call/2"},{"type":"function","title":"MainProxy.Plug.init/1","doc":"","ref":"MainProxy.Plug.html#init/1"},{"type":"behaviour","title":"MainProxy.Proxy","doc":"","ref":"MainProxy.Proxy.html"},{"type":"callback","title":"MainProxy.Proxy.backends/0","doc":"Specify the backends to pass requests to at startup time. (Optional)\n\nOverriding this callback allows for setting the backends to be matched at\nruntime when the proxy is starting up.\n\nExample:\n\n    @impl MainProxy.Proxy\n    def backends do\n      [\n        %{\n          domain: \"https://myapp1.com\",\n          phoenix_endpoint: MyApp1Web.Endpoint\n        },\n        %{\n          domain: \"https://myapp2.com\",\n          phoenix_endpoint: MyApp2Web.Endpoint\n        }\n      ]\n    end","ref":"MainProxy.Proxy.html#c:backends/0"},{"type":"callback","title":"MainProxy.Proxy.merge_config/2","doc":"Merge cowboy config\n\nOverriding this callback allows the configuration from the application\nenvironment to be modified at runtime.","ref":"MainProxy.Proxy.html#c:merge_config/2"},{"type":"type","title":"MainProxy.Proxy.scheme/0","doc":"","ref":"MainProxy.Proxy.html#t:scheme/0"}],"content_type":"text/markdown"}